@@ -1,7 +1,7 @@
 # -*- coding: latin-1 -*-
 
 """
-SimpleGUICS2Pygame package (July 13, 2013)
+SimpleGUICS2Pygame package (October 31, 2013)
 
 It is primarily a standard Python_ (2 **and** 3) module
 reimplementing the SimpleGUI particular module of CodeSkulptor_
@@ -9,7 +9,8 @@ reimplementing the SimpleGUI particular module of CodeSkulptor_
 
 Require Pygame_
 (except for the Timer class)
-(`Unofficial Windows Binaries`_).
+(`Unofficial Windows Binaries`_)
+(and must be installed separately).
 
 Module simpleplot require matplotlib_ .
 
@@ -30,6 +31,8 @@ http://www.opimedia.be/
 
 Started on May 21, 2013
 
+v.01.00.02 --- October 31, 2013
+v.01.00.01 --- October 9, 2013
 v.01.00.00 --- July 13, 2013
 v.00.92.00 --- June 27, 2013
 v.00.91.00 --- June 23, 2013
@@ -37,9 +40,9 @@ v.00.90.10 --- June 19, 2013
 v.00.90.00 --- June 13, 2013
 """
 
-_VERSION = '01.00.00'
+_VERSION = '01.00.02'
 """
-Version of simpleguics2pygame module.
+Version of SimpleGUICS2Pygame package.
 """
 
 _WEBSITE = 'https://bitbucket.org/OPiMedia/simpleguics2pygame'
